==> mdr-0.0.5.tgz: package/test.md <==

# Level 1 Header #
## Level 2 Header ##
### Level 3 Header ###
#### Level 4 Header ####
##### Level 5 Header #####
###### Level 6 Header ######

# Paragraphs #

He lives in North Hollywood on Radford, near the In-and-Out Burger. Felis ligula, malesuada suscipit malesuada non, ultrices non urna sed orci ipsum. Darkness warshed over the Dude— darker'n a black steer's tookus on a moonless prairie night. There was no bottom. Placerat id condimentum rutrum, rhoncus ac lorem aliquam placerat. The new technology permits us to do exciting things with interactive erotic software. Wave of the future, Dude. 100% electronic. Posuere neque, at dignissim magna.

He suspects that the culprits might be the very people who, uh, soiled your rug, and you're in a unique position to confirm or, uh, disconfirm that suspicion. Dolor sit amet, consectetur adipiscing elit praesent ac magna justo pellentesque ac lectus. Yes, so we were informed. However, we must of course transmit the remains to you in a receptacle. Quis elit blandit fringilla a ut turpis praesent.

# Line Breaks #

These lines should end with line breaks.  
These lines should end with line breaks.  
These lines should end with line breaks.  
These lines should end with line breaks.  

# Blockquotes #


 > This is a blockquote. The path of the righteous man is beset on all sides by the iniquities of the selfish and the tyranny of evil men. Blessed is he who, in the name of charity and good will, shepherds the weak through the valley of darkness, for he is truly his brother's keeper and the finder of lost children. And I will strike down upon thee with great vengeance and furious anger those who would attempt to poison and destroy My brothers. And you will know My name is the Lord when I lay My vengeance upon thee.

----------------

As you can see, nested blockquotes don't work.

 > Here are some nested blockquote. Dear Sir stroke Madam, I am writing to inform you of a fire which has broken out at the premises of... Graphic homoeroticism? Does that mean they're going to get them out? Hello? I've had a bit of a tumble. Unbelievable! Some idiot disabled his firewall, meaning all the computers on Seven are teeming with viruses, plus I've just had to walk all the way down the motherfudging stairs, because the lifts are broken AGAIN!
 > 
 > > Tomorrow vee come back und cut off your chonson. Here's the name and number of a doctor who will look at it for you. You will receive no bill. He's a good man. And thorough. Faucibus tristique nullam non accumsan justo nulla facilisi integer interdum elementum. Nihilists! Jesus.


# Lists #

## Unordered ##

* This
* One
* Is
* Unordered

## Ordered ##

Ordered lists have no numbers

---------------

1. This
2. Is
3. An
4. Ordered
5. List

## Nested Lists ##

Nested lists are borked too.

----------------

 1. Element One

      * foo
      * bar

 2. Element Two

 3. Element Three

        here's a thing
        and another thing

    This text is part of element three.

# Horizontal Rules #

---------------


# Code Blocks #

    var this_line = 'a block of code';
    this_line.is('also code');
    
    if (this.renders)  {
        kettle.fill().turnOn();
    }

# Inline Code #

Here's a paragraph with bits of code like `var foo = (bar * koala);` in it. Inline code `print('woo')` yay.

# Links #

[This is a link to Github](http://github.com)  
[This is another link](http://example.com)

# Emphasis and Strong #

I'm speaking normally here *but this bit has emphasis* because I feel it's important. And **this bit is really strong**, because seriously.

# Image #

![Image alt text](foo.jpg "Image title")

# Deletions #

This text has ~~mistay mistaek mitaks~~ things which have been corrected.

==> mdr-0.1.1.tgz: package/test.md <==

# Level 1 Header #
## Level 2 Header ##
### Level 3 Header ###
#### Level 4 Header ####
##### Level 5 Header #####
###### Level 6 Header ######

# Paragraphs #

He lives in North Hollywood on Radford, near the In-and-Out Burger. Felis ligula, malesuada suscipit malesuada non, ultrices non urna sed orci ipsum. Darkness warshed over the Dude— darker'n a black steer's tookus on a moonless prairie night. There was no bottom. Placerat id condimentum rutrum, rhoncus ac lorem aliquam placerat. The new technology permits us to do exciting things with interactive erotic software. Wave of the future, Dude. 100% electronic. Posuere neque, at dignissim magna.

He suspects that the culprits might be the very people who, uh, soiled your rug, and you're in a unique position to confirm or, uh, disconfirm that suspicion. Dolor sit amet, consectetur adipiscing elit praesent ac magna justo pellentesque ac lectus. Yes, so we were informed. However, we must of course transmit the remains to you in a receptacle. Quis elit blandit fringilla a ut turpis praesent.

# Line Breaks #

These lines should end with line breaks.  
These lines should end with line breaks.  
These lines should end with line breaks.  
These lines should end with line breaks.  

# Emphasis and Strong #

I'm speaking normally here *but this bit has emphasis* because I feel it's important. And **this bit is really strong**, because seriously. Here's some text ***that's strong and emphasised*** and for some reason is colored blue.

# Links #

[This is a link to Github](http://github.com)  
[This is another link](http://example.com)

# Code Blocks #

    var this_line = 'a block of code';
    this_line.is('also code');
    
    if (this.renders)  {
        kettle.fill().turnOn();
    }

# Inline Code #

Here's a paragraph with bits of code like `var foo = (bar * koala);` in it. Inline code `print('woo')` yay.

# Horizontal Rules #

---------------

# Blockquotes #

 > This is a blockquote. The path of the righteous man is beset on all sides by the iniquities of the selfish and the tyranny of evil men. Blessed is he who, in the name of charity and good will, shepherds the weak through the valley of darkness, for he is truly his brother's keeper and the finder of lost children. And I will strike down upon thee with great vengeance and furious anger those who would attempt to poison and destroy My brothers. And you will know My name is the Lord when I lay My vengeance upon thee.

----------------

As you can see, nested blockquotes don't work.

 > Here are some nested blockquote. Dear Sir stroke Madam, I am writing to inform you of a fire which has broken out at the premises of... Graphic homoeroticism? Does that mean they're going to get them out? Hello? I've had a bit of a tumble. Unbelievable! Some idiot disabled his firewall, meaning all the computers on Seven are teeming with viruses, plus I've just had to walk all the way down the motherfudging stairs, because the lifts are broken AGAIN!
 > 
 > > Tomorrow vee come back und cut off your chonson. Here's the name and number of a doctor who will look at it for you. You will receive no bill. He's a good man. And thorough. Faucibus tristique nullam non accumsan justo nulla facilisi integer interdum elementum. Nihilists! Jesus.


# Lists #

## Unordered ##

* This
* One
* Is
* Unordered

## Ordered ##

Ordered lists have no numbers

---------------

1. This
2. Is
3. An
4. Ordered
5. List

## Nested Lists ##

Nested lists are borked too.

----------------

 1. Element One

      * foo
      * bar

 2. Element Two

 3. Element Three

        here's a thing
        and another thing

    This text is part of element three.

# Image #

![Image alt text](foo.jpg "Image title")

# Deletions #

This text has ~~mistay mistaek mitaks~~ things which have been corrected.
